%% This Code replicates figures and tables from the paper 
% "Global Trends in Income Inequality and Income
%    Dynamics: New Insights from GRID"
% By Fatih Guvenen, Luigi Pistaferri and Giovanni L. Violante
% 
% This code was produced by: Francisco A. Bullano
% Date: 8/12/2022
%
% Figures: 1) Comparing Inequality Trends in GRID and WID
%          2)  Trends in Overall, Top-End, and Bottom-End Income Inequality
%          for GRID Countries
%          3) Growth in Top Percentiles Vs GDP Growth
%          4) Gender Differences in Inequality Trends
%          5) Density of Annual Change in Log Income, by Gender
%          6) Density of Annual Change in Log Income (Men)
%          7) Trends in Income Volatility (Men and Women)
%          8) Skewness Fluctuations over the Business Cycle (Men)
%          9) Standard Deviation of 5-Year Income Growth, by Permanent Income and Age (Men)
%          10) Skewness of 5-Year Income Growth, by Permanent Income and Age (Men)
%          11) Kurtosis of 5-Year Income Growth by Permanent Income (Men)
%          A.1) P9010 Differential of 5-Year Income Growth by Permanent Income (Men)
%          A.2) Kelley Skewness of 5-Year Income Growth by Permanent Income (Men)
%          A.3) Excess Crow Kurtosis of 5-Year Income Growth by Permanent
%          Income (Men)
%          A.4) Comparing Inequality P90-P10 
%          A.5) Comparing Inequality P90-P50
%          A.6) Comparing Inequality P50-P10 
% Tables: 2) Pareto Tail Indices of the Distribution of Log Annual Income Change
%         3) Cyclicality of the Moments of 1-year Log Income Change
%
%% Software Requirements:
% Matlab R2022a
% Matlab Econometric toolbox
% Export_figures exchange file
%% 

clear
%IMPORTANT: Current folder must be the SAME where this m_file is.

Main_directory=[eval('cd')];

%Sub Directories:
Figures_dir=[Main_directory '\Output_Figures\'];
Data_dir=[Main_directory '\Data\'];
Code_dir=[Main_directory '\Codes\'];
Output_Reg=[Main_directory '\Output_Reg\'];


Dir.Main_directory=Main_directory;
Dir.Figures_dir=Figures_dir;
Dir.Data_dir=Data_dir;
Dir.Code_dir=Code_dir;
Dir.Output_Reg=Output_Reg;


%% Step 1: Importing data
addpath(Code_dir)
% Importing data base with income dynamics statistics
Import_Stats
% Importing data base with density
Import_Density
% Importing GDP Growth
Import_GDP_growth
% Importing data base with Statistics by skill
Import_Rank
% Importing data with Inequality statistics 
Import_QE_Summary
% Importing data for Fig 3 
Import_Fig_3_data


%Code and name for each country we want to produce Outputs
% "Countries" must match the code in the data base
Countries = {'ARG' 'BRA' 'CAN' ...
    'DEN' 'FRA' 'GER' 'ITA' 'MEX' 'NOR' 'SPA' 'SWE' 'UK' 'US'}; 

%With this name will start each figure
Countries_name = {'Agentina' 'Brazil' 'Canada' 'Denmark'...
    'France' 'Germany' 'Italy' 'Mexico' 'Norway' 'Spain' 'Sweden' 'United Kingdom' 'United States'};

%Include Format for all figures. For details open Pull_Format.m
Pull_Format;

%% Section 1: Generates Figures
% 1.1: Generates Figures 1 to 11 and A1 to A6
%% Section 2: Generates Tables
% 2.1: Generates Table 2
% 2.2: Generates Table 3

%% Section 1:
%% Figure 1 : Comparing Inequality Trends in GRID and WID
%Code Updated: 8/12/2022
for i=1:length(Countries) 
try  
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_1\'];
code_plot=['Fig_1'];
variable_1=["country","year","gender","age"];
variables = ["gini_coefficient" "gini"];
if string(name)==string(['UK'])
variables = ["p9010_log_inc" "gini"];
end
age=['25-55'];
gender=["All genders"];
title_t=['Fig 1: Comparing Inequality Trends in GRID and WID'];
Figure_1_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,QEsummary);
catch
to_show=['Fig 1: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end

%% Figure 2: Inequality Trends in GRID
%Code Updated: 8/9/2022
Figure_name=['Figure_2\'];
code_plot=['Fig_2'];
title_t=['Fig 2: Inequality Trends in GRID '];
variable_1=["country","year","gender","age"];
variables = ["p9010_res_log_inc" "p9050_res_log_inc" "p5010_res_log_inc"];
age=['25-55']; 
name_figure=[''];

%Separate Gender
gender=["All genders"];

%Recover coefficients
[P9010,P9050,P5010,Success]= regresion_trend(Stats,Density,GDP_growth,variable_1,variables,age,gender,Format,Dir,QEsummary,Countries);

Figure_2_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,QEsummary,P9010,P9050,P5010,Countries);

%% Figure 3 : Growth in Top Percentiles Vs GDP Growth
%Code Updated: 
Figure_name=['Figure_3\'];
code_plot=['Fig_3'];
title_t=['Fig 3: Growth in Top Percentiles Vs GDP Growth  '];
variable_1=[];
variables = [];
age=[]; 
name_figure=[];
gender=[];

Figure_3_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,Rank,datafig3)

%% Figure 4 :  Gender Differences in Inequality Trends
%Code Updated: 8/09/2022
for i=1:length(Countries) 
try  
 %Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_4\'];
code_plot=['Fig_4'];
variable_1=["country","year","gender","age"];
variables = ["diff9010" "diff9050" "diff5010" ];
age=['25-55'];
gender=["Male"];
title_t=['Fig 4: Gender Differences in Inequality Trends'];
Figure_4_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,QEsummary);
catch
to_show=['Fig 4: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end


%% Figure 5:  Density Annual Change in Log Income, by Gender
%Code Updated: 8/9/2022
% For Canada i = 3
for i=3 
try  
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_5\'];
code_plot=['Fig_5'];
variable_1=["country","year","gender","age"];
variables = ["midp_bin_res_1yr_log_chg_distr" "dens_bin_res_1yr_log_chg_distr"];
age=['25-55'];
gender=["Male" "Female"];
title_t=['Fig 5: Density Annual Change in Log Income, by Gender'];
%Exporting 
Figure_5_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir);
catch
to_show=['Fig 5: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end

%% Figure 6: Density Annual Change in Log Income (Men)
%Code Updated: 6/16/2022
for i=1:length(Countries) 
try  
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_6\'];
code_plot=['Fig_6'];
variable_1=["country","year","gender","age"];
variables = ["midp_bin_res_1yr_log_chg_distr" "dens_bin_res_1yr_log_chg_distr"];
age=['25-55'];
gender=["Male"];
title_t=['Fig 6: Density Annual Change in Log Income (Men)'];

%Exporting 
Figure_6_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir);

catch
to_show=['Fig 6: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end


%% Figure 7: Trends in Income Volatility (Men and Women)
%Code Updated: 06/16/2022
for i=1:length(Countries) 
try   
 %Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_7\'];
code_plot=['Fig_7'];
variable_1=["country","year","gender","age"];
variables = ["std_res_1yr_log_chg"];
if string(name) =='UK'
% For UK P9010
 variables = ["p9010_res_1yr_log_chg"];
end
age=['25-55'];
gender=["Male" "Female"];
title_t=['Fig 7: Trends in Income Volatility (Men and Women)'];
Figure_7_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir);
catch
to_show=['Fig 7: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end


%% Figure 8: Skewness Fluctuations over the Business Cycle (Men)
%Code Updated: 6/17/2022
for i=1:length(Countries) 
try 
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_8\'];
code_plot=['Fig_8'];
variable_1=["country","year","gender","age"];
variables = ["kelley_res_1yr_log_chg"];
age=['25-55'];
gender=["Male"];
title_t=['Fig 8 : Skewness Fluctuations over the Business Cycle (Men)'];
Figure_8_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir);
catch
to_show=['Fig 8: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end

%% Figure 9: Standard Deviation of 5-Year Income Growth, by Permanent Income and Age (Men)
%Code Updated: 7/06/2022
for i=1:length(Countries) 
try 
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_9\'];
code_plot=['Fig_9'];
variable_1=["country","year","gender","age","rank_permanent_inc"];
variables = ["std_res_5yr_log_chg_by_skill"];

if string(name) =='UK'
% For UK P9010
 variables = ["std_res_5yr_log_chg_by_skill"];
end

age=["25-34" "35-44" "45-55" ];
gender=["Male"];
title_t=['Fig 9: Standard Deviation of 5-Year Income Growth, by Permanent Income and Age (Men)'];
Figure_9_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,Rank);
catch
to_show=['Fig 9 : Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end

%% Figure 10: Skewness of 5-Year Income Growth, by Permanent Income and Age (Men)
%Code Updated: 7/16/2022
for i=1:length(Countries) 
try   
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_10\'];
code_plot=['Fig_10'];
variable_1=["country","year","gender","age","rank_permanent_inc"];
variables = ["skew_res_5yr_log_chg_by_skill"];


if string(name) =='UK'
% For UK P9010
 variables = ["skew_res_5yr_log_chg_by_skill"];
end
age=["25-34" "35-44" "45-55" ];
gender=["Male"];
title_t=['Fig 10: Skewness of 5-Year Income Growth, by Permanent Income and Age (Men)'];
Figure_10_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,Rank);
catch
to_show=['Fig 10: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end

%% Figure 11: Kurtosis of 5-Year Income Growth by Permanent Income (Men)
%Code Updated: 8/06/2022
for i=1:length(Countries) 
try 
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_11\'];
code_plot=['Fig_11'];
variable_1=["country","year","gender","age","rank_permanent_inc"];
variables = ["kurt_res_5yr_log_chg_by_skill"];

if string(name) =='UK'
% For UK P9010
 variables = ["kurt_res_5yr_log_chg_by_skill"];
end

age=["25-34" "35-44" "45-55" ];
gender=["Male"];
title_t=['Fig 11: Kurtosis of 5-Year Income Growth by Permanent Income (Men)'];
Figure_11_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,Rank);
catch
to_show=['Fig 11: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end


%% Figure A.1: P9010 Differential of 5-Year Income Growth by Permanent Income (Men)
%Code Updated: 8/16/2022
for i=1:length(Countries) 
try 
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_A_1\'];
code_plot=['Fig_A_1'];
variable_1=["country","year","gender","age","rank_permanent_inc"];
variables = ["p9010_res_5yr_log_chg_by_skill"];

if string(name) =='UK'
% For UK P9010
 variables = ["p9010_res_1yr_log_chg_by_skill"];
end

age=["25-34" "35-44" "45-55" ];
gender=["Male"];
title_t=['Fig A1: P9010 Differential of 5-Year Income Growth by Permanent Income (Men)'];
Figure_A_1_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,Rank);
catch
to_show=['Fig A1: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end



%% Figure A.2: Kelley Skewness of 5-Year Income Growth by Permanent Income (Men)
%Code Updated: 8/16/2022
for i=1:length(Countries) 
try 
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_A_2\'];
code_plot=['Fig_A_2'];
variable_1=["country","year","gender","age","rank_permanent_inc"];
variables = ["kelley_res_5yr_log_chg_by_skill"];

if string(name) =='UK'
% For UK P9010
 variables = ["kelley_res_1yr_log_chg_by_skill"];
end

age=["25-34" "35-44" "45-55" ];
gender=["Male"];
title_t=['Fig A2: Kelley Skewness of 5-Year Income Growth by Permanent Income (Men)'];
Figure_A_2_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,Rank);
catch
to_show=['Fig A2: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end

%% Figure A.3: Excess Crow Kurtosis of 5-Year Income Growth by Permanent Income (Men)
%Code Updated: 8/16/2022
for i=1:length(Countries) 
try 
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_A_3\'];
code_plot=['Fig_A_3'];
variable_1=["country","year","gender","age","rank_permanent_inc"];
variables = ["crows_res_5yr_log_chg_by_skill"];

if string(name) =='UK'
% For UK P9010
 variables = ["crows_res_1yr_log_chg_by_skill"];
end

age=["25-34" "35-44" "45-55" ];
gender=["Male" ];
title_t=['Fig A3: Excess Crow Kurtosis of 5-Year Income Growth by Permanent Income (Men)'];
Figure_A_3_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,Rank);
catch
to_show=['Fig A3: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end

%% Figure A.4: Comparing Inequality P90-P10  
%Code Updated: 07/26/2022
for i=1:length(Countries) 
try  
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_A_4\'];
code_plot=['Fig_A_4'];
variable_1=["country","year","gender","age"];
variables = ["p9010_res_log_inc"];
if string(name)==string(['UK'])
variables = ["p9010_res_log_inc"];
end
age=['25-55'];
gender=["Male", "Female"];
title_t=['Fig A.4: Comparing Inequality P90-P10'];

Figure_A_4_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,QEsummary);

catch
to_show=['Fig A4: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end


%% Figure A.5 : Comparing Inequality P90-P50  
%Code Updated: 07/27/2022
for i=1:length(Countries) 
try  
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_A_5\'];
code_plot=['Fig_A_5'];
variable_1=["country","year","gender","age"];
variables = ["p9050_res_log_inc"];
if string(name)==string(['UK'])
variables = ["p9050_res_log_inc"];
end
age=['25-55'];
gender=["Male", "Female"];
title_t=['Fig A.5: Comparing Inequality P90-P50'];

Figure_A_5_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,QEsummary);

catch
to_show=['Fig A5: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end

%% Figure A.6: Comparing Inequality P50-P10  
%Code Updated: 06/15/2022
for i=1:length(Countries) 
try  
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Figure_A_6\'];
code_plot=['Fig_A_6'];
variable_1=["country","year","gender","age"];
variables = ["p5010_res_log_inc"];
if string(name)==string(['UK'])
variables = ["p5010_res_log_inc"];
end
age=['25-55'];
gender=["Male", "Female"];
title_t=['Fig A.6: Comparing Inequality P50-P10   '];
Figure_A_6_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,QEsummary);
catch
to_show=['Fig A6: Plot for Country ' name ' was skipped'];   
display(to_show);    
end
end

%% Section 2: 
%% Section 2: Generates Tables
% 2.1: Generates Table 2 
%% Generate Table 2
%Code Updated: 
Table_2 = struct;
Table_2.Country = [];
Table_2.Left_Slope = [];
Table_2.Right_Slope =[] ;
Table_2.Difference=[];
Table_2.Sd=[];
Table_2.Gender =[];

for i=1:length(Countries) 
try   
%Code start here
name=[char(Countries(i))];
name_figure=[char(Countries_name(i))];
Figure_name=['Table_2\'];
code_plot=['Tab_2'];
variable_1=["country","year","gender","age"];
variables = ["midp_bin_res_1yr_log_chg_distr" "dens_bin_res_1yr_log_chg_distr"];
age=['25-55'];
gender=["Male"];
title_t=['Table 2'];

%Exporting 
Y=Table_2_rf(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir);
Table_2.Country = [Table_2.Country Y.country];
Table_2.Left_Slope = [Table_2.Left_Slope Y.left_slope];
Table_2.Right_Slope =[Table_2.Right_Slope Y.right_slope] ;
Table_2.Difference =[Table_2.Difference Y.Diff];
Table_2.Sd =[Table_2.Sd Y.Sd];

Table_2.Gender = [Table_2.Gender Y.gender];

catch
to_show=['Calculation for Country ' name ' was skipped'];   
display(to_show);    
end
end

% Creating Table 2
c = char( hex2dec('0394') );
d = char( hex2dec('03C3') );
row_names={'Left Tail' 'Right Tail' 'L - |R|' [ d '(' c 'Y)']};
tab_2=array2table([Table_2.Left_Slope ;Table_2.Right_Slope;Table_2.Difference;Table_2.Sd],"VariableNames",strcat(Table_2.Country,Table_2.Gender),RowNames=row_names);

%Saving results
Save_Table_2


%% 2.2: Generate Table 3
%General Varibles: Do not change
variable_1=["country","year","gender","age"]; 

% Left Hand Side Variables
variables = ["kelley_res_1yr_log_chg" "p9010_res_1yr_log_chg" "p9050_res_1yr_log_chg" "p5010_res_1yr_log_chg" ...
      "crows_res_1yr_log_chg"]; 

%Type of age we want
age=['25-55']; 

%Separate Gender
gender=["Male" "Female"]; 

%Run Regresion and Store in Excel Table_3.xls
Y=Regresion_table_3(Stats,Density,GDP_growth,name,name_figure,Figure_name,code_plot,variable_1,variables,age,gender,title_t,Format,Dir,Countries,Countries_name);
